
#
########################################################################
#  SCRIPT APPELE DANS ~cft/filinst/PROD/RECV_CFT/recv_ok.cft
########################################################################
#

#=========================================================================
#
#  Redacteur   : JF.GONZALEZ GARCIA
#  Copyright   : CIMAFAP-NANTERRE
#  date        : 09 avril 2008
#  Projet      : CFT et flux SAS
#  Version     : 1.0
#
#  Description : - Mise a disposition des echanges SAS recus par CFT 
#                 dans le FS du domaine specifie dans le champ PARM
#                - Ce traitement  genera un script dans le sas 
#                           /apps/products/cft/filinst/PROD/TRT_WSASMADE/A_Faire
#                 qui une fois execute par le daemon sous ControlM WCKCFT06JO - scruteur
#                 montera les tables ControlM pour effectue les 
#                 etapes decrites dans le fichier ./TRT_WSASMADE/WSASMADE_steps.txt
#
#
#--------------------------------------------------------------------------------------
#--------------------------------------------------------------------------------------

function Step_Main
{
#==== Incrementer les steps 
    (( cstep+=1 ))
    libstep=${libtab[${cstep}]}
    procstep=${proctab[${cstep}]}
    Proprio=${proprio[${cstep}]}
    if [ ${cstep} -lt 10 ]; then
       Step="0"$cstep
    else
       Step=${cstep}
    fi
}

#
#=============================================================================================================
#============== DEBUT TRT 
#=============================================================================================================
#

set -a

#------------- parametres generaux

HomeTrt=/apps/products/cft/filinst/PROD/TRT_WSASMADE

#============================================================
# Les Differents steps sont inscrits dans WSASMADE_steps.txt
#========== creation de la libtab = libelle des steps
#========== creation de la proctab = steps a executer
#============================================================

 i_nbre_procs=0

 while read ligne
    do
      case $ligne in
        [0-9]*)
               (( i_nbre_procs+=1 ))
               j="$( echo $ligne | cut -d# -f1 )"
               if [ $j -ne ${i_nbre_procs} ]; then
                  echo "Probleme dans fichier  WSASMADE_steps.txt au step $j \n $ligne"
                  Send_Err
               fi
                  proctab[${i_nbre_procs}]="$( echo $ligne | cut -d# -f2 )"
                  proprio[${i_nbre_procs}]="$( echo $ligne | cut -d# -f3 )"
                  libtab[${i_nbre_procs}]="$( echo $ligne | cut -d# -f4 )"
               ;;
      esac
    done < ${HomeTrt}/WSASMADE_steps.txt


#------- nom du script final lance par le DAEMON scruteur
  test -d "/apps/products/cft/filinst/PROD/TRT_WSASMADE/A_Faire" || mkdir /apps/products/cft/filinst/PROD/TRT_WSASMADE/A_Faire
  SASMAD_script=/apps/products/cft/filinst/PROD/TRT_WSASMADE/A_Faire/${Cft_idf}_${Cft_idtu}_${Cft_parm}_$$

#
#=============================================================================================================
#  Preparation du script qui sera execute par le DAEMON WSASMADE_daemon.ksh ( voir job dans table CTM WCKCFT06JO )
#=============================================================================================================
#
#--------- variables pour tables controlm
  TYPEJOB=JOB
  #TYPEJOB=DUMMY
  USERSHOUT="prodtechunix"

#=========== Parametres passes par ControlM dans -CTM
  Group=WCKSAS${Cft_idtu}T
  Jobname=CKSASMAD
  Schedtab=${Group}
  Nodeid=CK_SAS
  Appli=CK_SAS
  MACHINE=$( echo ${Appli} | cut -c1-2 )
  Proprio=cft

#=========== Repertoire de depot des fichiers reus suivant emetteur initial
      case ${Cft_suser} in
#====== MVS ou Helios en provenance de Lacan donc flux de PROD
           M00PU00|UA0PU00) RepDepotSAS="Z_PRODUCTION"  ;;
#====== si directement de Lacan pour tester 
           UCKPUA0) RepDepotSAS="Y_PRODUCTION_SIMUCENTRE" ;;
      esac


  PREFJOB=${MACHINE}SAS${Cft_idtu}
    

#-------- Creation des jobs Controlm
#========== Autant de jobs que de steps
  Step=0 ; cstep=0 ; Step_prev=0
  j_nbre_procs=1


set -e


cat << @@EOFF > ${SASMAD_script}
#!/bin/ksh
#----------------------------------------------------------------------
# Traitement mise a disposition fichier WSASMADE sur FS domaine SAS
#----------------------------------------------------------------------
#
#-------- donne par le scruteur qui lancera ce script
  ODAT=\${1}

export PATH=${PATH}:/apps/products/ctmagent/REEL/ctm/exe
export LIBPATH=/apps/products/ctmagent/REEL/ctm/exe:${LIBPATH}
export CONTROLM=/apps/products/ctmagent/REEL/ctm
CR1=0 

@@EOFF

  while [ ${j_nbre_procs} -le ${i_nbre_procs} ]
  do
    Step_Main
 
cat << @@EOFF >> ${SASMAD_script}
/apps/products/ctmagent/REEL/ctm/exe/ctmcreate -TASKTYPE ${TYPEJOB} \\
-SCHEDTAB ${Schedtab} \\
-GROUP ${Group} \\
-GROUP_ORD LAST \\
-ODATE \${ODAT} \\
-NODEGRP ${Nodeid} \\
-JOBNAME ${PREFJOB}${Step}T \\
-APPLICATION ${Appli} \\
-MEMNAME `basename ${procstep}` \\
-MEMLIB  `dirname ${procstep}` \\
-OWNER ${Proprio} \\
-AUTHOR "xxgon" \\
-DESCRIPTION "[${Step}] `echo $libstep | awk '{ print substr($0,1,30)}` " \\
-MAXRERUN 5 \\
-MAXWAIT 5 \\
@@EOFF

if [ ${Step_prev} -ne 0 ]; then
cat << @@EOFF >> ${SASMAD_script}
-INCOND 'JB-OK-${PREFJOB}${Step_prev}T-${PREFJOB}${Step}T' \${ODAT} AND \\
-OUTCOND 'JB-OK-${PREFJOB}${Step_prev}T-${PREFJOB}${Step}T' \${ODAT} DEL \\
@@EOFF
else
cat << @@EOFF >> ${SASMAD_script}
-INCOND 'JB-OK-${PREFJOB}_$$' \${ODAT} AND \\
-OUTCOND 'JB-OK-${PREFJOB}_$$' \${ODAT} DEL \\
@@EOFF
fi

if [ ${j_nbre_procs} -lt ${i_nbre_procs} ]; then
Step_prev=$Step
 Step_Main
Step_next=$Step

cat << @@EOFF >> ${SASMAD_script}
-OUTCOND 'JB-OK-${PREFJOB}${Step_prev}T-${PREFJOB}${Step_next}T' \${ODAT} ADD \\
@@EOFF

 (( cstep-=2 ))
 Step_Main
fi
#*************************modif du 26 novembre 2008*********************
#-AUTOEDIT %%PARM2 "/DATASAS/DERSSTAT/${Cft_parm}/DONNEES/FICHIERS" \\
#*************************modif du 10 fevrier 2010*********************
#-SHOUT OK ${USERSHOUT} R "%%DATACENTER. - %%JOBNAME. - %%TIME. - %%COMPSTAT. OK !" \\
#***********************************************************************
cat << @@EOFF >> ${SASMAD_script}
-QUANTITATIVE MAX_${MACHINE} 1 \\
-QUANTITATIVE MAX_CK_MADSAS 1 \\
-CONTROL MAX_CKSASMAD E \\
-AUTOEDIT %%PARM1 "${Cft_fname}" \\
-AUTOEDIT %%PARM2 "/DATASAS/DERSSTAT/${Cft_parm}/DONNEES/FICHIERS/${RepDepotSAS}" \\
-AUTOEDIT %%PARM3 "${Cft_idf}" \\
-AUTOEDIT %%PARM4 "${Cft_parm}" \\
-AUTOEDIT %%PARM5 "${Cft_idtu}" \\
-AUTOEDIT %%PARM6 "${Cft_nfname}" \\
-SHOUT NOTOK ${USERSHOUT} R "%%DATACENTER. - %%JOBNAME. - %%TIME. - %%COMPSTAT. KO !"
(( CR1+=\$? ))

@@EOFF

    (( j_nbre_procs+=1 ))
    Step_prev=${Step}
done

cat << @@EOFF >> ${SASMAD_script}
if test \${CR1} -eq 0
then
#---------- Pour demarrer l ensemble des scripts
/apps/products/ctmagent/REEL/ctm/exe/ctmcreate -TASKTYPE DUMMY \\
-SCHEDTAB ${Schedtab} \\
-GROUP ${Group} \\
-GROUP_ORD LAST \\
-ODATE \${ODAT} \\
-NODEGRP ${Nodeid} \\
-APPLICATION ${Appli} \\
-OWNER ${Proprio} \\
-AUTHOR "xxgon" \\
-DESCRIPTION "[00] Feu vert ${PREFJOB}" \\
-MAXRERUN 5 \\
-MAXWAIT 5 \\
-OUTCOND 'JB-OK-${PREFJOB}_$$' \${ODAT} ADD
(( CR1+=\$? ))
fi

#--------------- fin
exit \${CR1}

@@EOFF

set +a
set +e
#------------ fin script WSASMADE
